@@ -6,7 +6,7 @@
  Description: 
  License:
 
-   Copyright (c) 2007-2015 Daniel Adler <dadler@uni-goettingen.de>, 
+   Copyright (c) 2007-2020 Daniel Adler <dadler@uni-goettingen.de>, 
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -33,22 +33,17 @@
 #include "dyncall_alloc.h"
 #include "dyncall_struct.h"
 
-static DCCallVM* dc_callvm_new_x64(DCCallVM_vt* vt, DCsize size)
-{
-  DCCallVM_x64* self = (DCCallVM_x64*)dcAllocMem(sizeof(DCCallVM_x64)+size);
-  
-  dc_callvm_base_init(&self->mInterface, vt);
 
-  /* Since we store register parameters in DCCallVM_x64 directly, adjust the stack size. */
-  size -= sizeof(DCRegData_x64);
-  size = (((signed long)size) < 0) ? 0 : size;
+/* 
+** x64 SystemV calling convention 
+**
+** - hybrid return-type call (bool ... pointer)
+**
+*/
 
-
-  self->mRegCount.i = self->mRegCount.f =  0;
-
-  dcVecInit(&self->mVecHead, size);
-  return (DCCallVM*)self;
-}
+void dcCall_x64_sysv(DCsize stacksize, DCpointer stackdata, DCpointer regdata_i, DCpointer regdata_f, DCpointer target);
+void dcCall_x64_win64(DCsize stacksize, DCpointer stackdata, DCpointer regdata, DCpointer target);
+void dcCall_x64_syscall_sysv(DCpointer argdata, DCpointer target);
 
 
 static void dc_callvm_free_x64(DCCallVM* in_self)
@@ -61,20 +56,7 @@ static void dc_callvm_reset_x64(DCCallVM* in_self)
 {
   DCCallVM_x64* self = (DCCallVM_x64*)in_self;
   dcVecReset(&self->mVecHead);
-  self->mRegCount.i = self->mRegCount.f =  0;
-}
-
-
-static void dc_callvm_mode_x64(DCCallVM* self, DCint mode)
-{
-  switch(mode) {
-    case DC_CALL_C_DEFAULT:
-    case DC_CALL_C_ELLIPSIS:
-      break;
-    default:
-      self->mError = DC_ERROR_UNSUPPORTED_MODE;
-      break;
-  }
+  self->mRegCount.i = self->mRegCount.f = 0;
 }
 
 
@@ -188,6 +170,8 @@ void dc_callvm_call_x64(DCCallVM* in_self, DCpointer target)
 }
 
 
+static void dc_callvm_mode_x64(DCCallVM* in_self, DCint mode);
+
 DCCallVM_vt gVT_x64 =
 {
   &dc_callvm_free_x64
@@ -195,7 +179,7 @@ DCCallVM_vt gVT_x64 =
 , &dc_callvm_mode_x64
 , &dc_callvm_argBool_x64
 , &dc_callvm_argChar_x64
-, &dc_callvm_argShort_x64 
+, &dc_callvm_argShort_x64
 , &dc_callvm_argInt_x64
 , &dc_callvm_argLong_x64
 , &dc_callvm_argLongLong_x64
@@ -217,13 +201,96 @@ DCCallVM_vt gVT_x64 =
 };
 
 
-DCCallVM* dcNewCallVM_x64(DCsize size) 
+/* --- syscall ------------------------------------------------------------- */
+
+#include <assert.h>
+void dc_callvm_call_x64_syscall_sysv(DCCallVM* in_self, DCpointer target)
 {
-  return dc_callvm_new_x64(&gVT_x64, size);
+  DCCallVM_x64* self;
+
+  /* syscalls can have up to 6 args, required to be "Only values of class INTEGER or class MEMORY" (from */
+  /* SysV manual), so we can use self->mRegData.i directly; verify this has space for at least 6 values, though. */
+  assert(numIntRegs >= 6);
+
+  self = (DCCallVM_x64*)in_self;
+  dcCall_x64_syscall_sysv(self->mRegData.i, target);
 }
 
+DCCallVM_vt gVT_x64_syscall_sysv =
+{
+  &dc_callvm_free_x64
+, &dc_callvm_reset_x64
+, &dc_callvm_mode_x64
+, &dc_callvm_argBool_x64
+, &dc_callvm_argChar_x64
+, &dc_callvm_argShort_x64
+, &dc_callvm_argInt_x64
+, &dc_callvm_argLong_x64
+, &dc_callvm_argLongLong_x64
+, &dc_callvm_argFloat_x64
+, &dc_callvm_argDouble_x64
+, &dc_callvm_argPointer_x64
+, NULL /* argStruct */
+, (DCvoidvmfunc*)       &dc_callvm_call_x64_syscall_sysv
+, (DCboolvmfunc*)       &dc_callvm_call_x64_syscall_sysv
+, (DCcharvmfunc*)       &dc_callvm_call_x64_syscall_sysv
+, (DCshortvmfunc*)      &dc_callvm_call_x64_syscall_sysv
+, (DCintvmfunc*)        &dc_callvm_call_x64_syscall_sysv
+, (DClongvmfunc*)       &dc_callvm_call_x64_syscall_sysv
+, (DClonglongvmfunc*)   &dc_callvm_call_x64_syscall_sysv
+, (DCfloatvmfunc*)      &dc_callvm_call_x64_syscall_sysv
+, (DCdoublevmfunc*)     &dc_callvm_call_x64_syscall_sysv
+, (DCpointervmfunc*)    &dc_callvm_call_x64_syscall_sysv
+, NULL /* callStruct */
+};
+
+
+
+/* mode */
+
+static void dc_callvm_mode_x64(DCCallVM* in_self, DCint mode)
+{
+  DCCallVM_x64* self = (DCCallVM_x64*)in_self;
+  DCCallVM_vt* vt;
+
+  switch(mode) {
+    case DC_CALL_C_DEFAULT:
+#if defined(DC_UNIX)
+    case DC_CALL_C_X64_SYSV:
+#else
+    case DC_CALL_C_X64_WIN64:
+#endif
+    case DC_CALL_C_ELLIPSIS:
+    case DC_CALL_C_ELLIPSIS_VARARGS:
+      vt = &gVT_x64;
+      break;
+    case DC_CALL_SYS_DEFAULT:
+# if defined DC_UNIX
+    case DC_CALL_SYS_X64_SYSCALL_SYSV:
+      vt = &gVT_x64_syscall_sysv; break;
+# else
+      self->mInterface.mError = DC_ERROR_UNSUPPORTED_MODE; return;
+# endif
+    default:
+      self->mInterface.mError = DC_ERROR_UNSUPPORTED_MODE; 
+      return;
+  }
+  dc_callvm_base_init(&self->mInterface, vt);
+}
+
+/* Public API. */
 DCCallVM* dcNewCallVM(DCsize size)
 {
-  return dcNewCallVM_x64(size);
+  DCCallVM_x64* p = (DCCallVM_x64*)dcAllocMem(sizeof(DCCallVM_x64)+size);
+
+  dc_callvm_mode_x64((DCCallVM*)p, DC_CALL_C_DEFAULT);
+
+  /* Since we store register parameters in DCCallVM_x64 directly, adjust the stack size. */
+  size -= sizeof(DCRegData_x64);
+  size = (((signed long)size) < 0) ? 0 : size;
+  dcVecInit(&p->mVecHead, size);
+  dc_callvm_reset_x64((DCCallVM*)p);
+
+  return (DCCallVM*)p;
 }
 
