@@ -6,7 +6,7 @@
  Description: 
  License:
 
-   Copyright (c) 2007-2015 Daniel Adler <dadler@uni-goettingen.de>, 
+   Copyright (c) 2007-2018 Daniel Adler <dadler@uni-goettingen.de>, 
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -42,7 +42,6 @@
 #define DYNCALL_CALLVM_X64_H
 
 #include "dyncall_macros.h"
-#include "dyncall_call_x64.h"
 #include "dyncall_callvm.h"
 #include "dyncall_vector.h"
 
@@ -105,8 +104,5 @@ typedef struct
   DCVecHead      mVecHead;    /* Parameters to be pushed onto stack.                     */
 } DCCallVM_x64;
 
-DCCallVM* dcNewCallVM_x64(DCsize size);
-
-
 #endif /* DYNCALL_CALLVM_X64_H */
 
