@@ -6,7 +6,7 @@
  Description: Call VM for x86 architecture implementation
  License:
 
-   Copyright (c) 2007-2015 Daniel Adler <dadler@uni-goettingen.de>, 
+   Copyright (c) 2007-2020 Daniel Adler <dadler@uni-goettingen.de>, 
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -29,21 +29,27 @@
 #include "dyncall_alloc.h"
 
 
+/* 
+** x86 calling convention calls 
+**
+** - hybrid return-type call (bool ... pointer)
+**
+*/
+
+#if defined(DC__OS_Plan9) /* No support for other cconvs on Plan9 and vice-versa. */
+void dcCall_x86_plan9               (DCpointer target, DCpointer stackdata, DCsize size);
+#else
+void dcCall_x86_cdecl               (DCpointer target, DCpointer stackdata, DCsize size);
+void dcCall_x86_win32_std           (DCpointer target, DCpointer stackdata, DCsize size);
+void dcCall_x86_win32_fast          (DCpointer target, DCpointer stackdata, DCsize size);
+void dcCall_x86_win32_msthis        (DCpointer target, DCpointer stackdata, DCsize size);
+void dcCall_x86_syscall_int80h_linux(DCpointer target, DCpointer stackdata, DCsize size);
+void dcCall_x86_syscall_int80h_bsd  (DCpointer target, DCpointer stackdata, DCsize size);
+#endif
+
+
 void dc_callvm_mode_x86(DCCallVM* in_self, DCint mode);
 
-/* call vm allocator */
-
-static DCCallVM* dc_callvm_new_x86(DCCallVM_vt* vt, DCsize size)
-{
-  DCCallVM_x86* self = (DCCallVM_x86*) dcAllocMem( sizeof(DCCallVM_x86)+size );
-
-  dc_callvm_base_init(&self->mInterface, vt);
-
-  self->mIntRegs              = 0;
-  dcVecInit(&self->mVecHead, size);
-  return (DCCallVM*) self;
-}
-
 /* call vm destructor */
 
 static void dc_callvm_free_x86(DCCallVM* in_self)
@@ -186,11 +192,6 @@ DCCallVM_vt gVT_x86_plan9 =
 , NULL /* callStruct */
 };
 
-DCCallVM* dcNewCallVM_x86_plan9(DCsize size) 
-{ 
-  return dc_callvm_new_x86( &gVT_x86_plan9, size );
-}
-
 
 #else
 
@@ -231,11 +232,6 @@ DCCallVM_vt gVT_x86_cdecl =
 , NULL /* callStruct */
 };
 
-DCCallVM* dcNewCallVM_x86_cdecl(DCsize size) 
-{ 
-  return dc_callvm_new_x86( &gVT_x86_cdecl, size );
-}
-
 
 
 /* --- stdcall -------------------------------------------------------------- */
@@ -278,12 +274,6 @@ DCCallVM_vt gVT_x86_win32_std =
 , NULL /* callStruct */
 };
 
-/* win32/std callvm allocator */
-
-DCCallVM* dcNewCallVM_x86_win32_std(DCsize size) 
-{ 
-  return dc_callvm_new_x86( &gVT_x86_win32_std, size );
-}
 
 /* --- fastcall common (ms/gnu) -------------------------------------------- */
 
@@ -389,10 +379,6 @@ DCCallVM_vt gVT_x86_win32_fast_ms =
 , NULL /* callStruct */
 };
 
-DCCallVM* dcNewCallVM_x86_win32_fast_ms(DCsize size) 
-{ 
-  return dc_callvm_new_x86( &gVT_x86_win32_fast_ms, size );
-}
 
 /* --- gnu fastcall -------------------------------------------------------- */
 
@@ -487,10 +473,6 @@ DCCallVM_vt gVT_x86_win32_fast_gnu =
 , NULL /* callStruct */
 };
 
-DCCallVM* dcNewCallVM_x86_win32_fast_gnu(DCsize size) 
-{ 
-  return dc_callvm_new_x86( &gVT_x86_win32_fast_gnu, size );
-}
 
 /* --- this ms ------------------------------------------------------------- */
 
@@ -536,19 +518,19 @@ DCCallVM_vt gVT_x86_win32_this_ms =
 
 /* call syscall */
 
-void dc_callvm_call_x86_sys_int80h_linux(DCCallVM* in_self, DCpointer target)
+void dc_callvm_call_x86_syscall_int80h_linux(DCCallVM* in_self, DCpointer target)
 {
   DCCallVM_x86* self = (DCCallVM_x86*) in_self;
-  dcCall_x86_sys_int80h_linux( target, dcVecData(&self->mVecHead), dcVecSize(&self->mVecHead) );
+  dcCall_x86_syscall_int80h_linux( target, dcVecData(&self->mVecHead), dcVecSize(&self->mVecHead) );
 }
 
-void dc_callvm_call_x86_sys_int80h_bsd(DCCallVM* in_self, DCpointer target)
+void dc_callvm_call_x86_syscall_int80h_bsd(DCCallVM* in_self, DCpointer target)
 {
   DCCallVM_x86* self = (DCCallVM_x86*) in_self;
-  dcCall_x86_sys_int80h_bsd( target, dcVecData(&self->mVecHead), dcVecSize(&self->mVecHead) );
+  dcCall_x86_syscall_int80h_bsd( target, dcVecData(&self->mVecHead), dcVecSize(&self->mVecHead) );
 }
 
-DCCallVM_vt gVT_x86_sys_int80h_linux =
+DCCallVM_vt gVT_x86_syscall_int80h_linux =
 {
   &dc_callvm_free_x86
 , &dc_callvm_reset_x86
@@ -563,20 +545,20 @@ DCCallVM_vt gVT_x86_sys_int80h_linux =
 , &dc_callvm_argDouble_x86
 , &dc_callvm_argPointer_x86
 , NULL /* argStruct */
-, (DCvoidvmfunc*)       &dc_callvm_call_x86_sys_int80h_linux
-, (DCboolvmfunc*)       &dc_callvm_call_x86_sys_int80h_linux
-, (DCcharvmfunc*)       &dc_callvm_call_x86_sys_int80h_linux
-, (DCshortvmfunc*)      &dc_callvm_call_x86_sys_int80h_linux
-, (DCintvmfunc*)        &dc_callvm_call_x86_sys_int80h_linux
-, (DClongvmfunc*)       &dc_callvm_call_x86_sys_int80h_linux
-, (DClonglongvmfunc*)   &dc_callvm_call_x86_sys_int80h_linux
-, (DCfloatvmfunc*)      &dc_callvm_call_x86_sys_int80h_linux
-, (DCdoublevmfunc*)     &dc_callvm_call_x86_sys_int80h_linux
-, (DCpointervmfunc*)    &dc_callvm_call_x86_sys_int80h_linux
+, (DCvoidvmfunc*)       &dc_callvm_call_x86_syscall_int80h_linux
+, (DCboolvmfunc*)       &dc_callvm_call_x86_syscall_int80h_linux
+, (DCcharvmfunc*)       &dc_callvm_call_x86_syscall_int80h_linux
+, (DCshortvmfunc*)      &dc_callvm_call_x86_syscall_int80h_linux
+, (DCintvmfunc*)        &dc_callvm_call_x86_syscall_int80h_linux
+, (DClongvmfunc*)       &dc_callvm_call_x86_syscall_int80h_linux
+, (DClonglongvmfunc*)   &dc_callvm_call_x86_syscall_int80h_linux
+, (DCfloatvmfunc*)      &dc_callvm_call_x86_syscall_int80h_linux
+, (DCdoublevmfunc*)     &dc_callvm_call_x86_syscall_int80h_linux
+, (DCpointervmfunc*)    &dc_callvm_call_x86_syscall_int80h_linux
 , NULL /* callStruct */
 };
 
-DCCallVM_vt gVT_x86_sys_int80h_bsd =
+DCCallVM_vt gVT_x86_syscall_int80h_bsd =
 {
   &dc_callvm_free_x86
 , &dc_callvm_reset_x86
@@ -591,27 +573,20 @@ DCCallVM_vt gVT_x86_sys_int80h_bsd =
 , &dc_callvm_argDouble_x86
 , &dc_callvm_argPointer_x86
 , NULL /* argStruct */
-, (DCvoidvmfunc*)       &dc_callvm_call_x86_sys_int80h_bsd
-, (DCboolvmfunc*)       &dc_callvm_call_x86_sys_int80h_bsd
-, (DCcharvmfunc*)       &dc_callvm_call_x86_sys_int80h_bsd
-, (DCshortvmfunc*)      &dc_callvm_call_x86_sys_int80h_bsd
-, (DCintvmfunc*)        &dc_callvm_call_x86_sys_int80h_bsd
-, (DClongvmfunc*)       &dc_callvm_call_x86_sys_int80h_bsd
-, (DClonglongvmfunc*)   &dc_callvm_call_x86_sys_int80h_bsd
-, (DCfloatvmfunc*)      &dc_callvm_call_x86_sys_int80h_bsd
-, (DCdoublevmfunc*)     &dc_callvm_call_x86_sys_int80h_bsd
-, (DCpointervmfunc*)    &dc_callvm_call_x86_sys_int80h_bsd
+, (DCvoidvmfunc*)       &dc_callvm_call_x86_syscall_int80h_bsd
+, (DCboolvmfunc*)       &dc_callvm_call_x86_syscall_int80h_bsd
+, (DCcharvmfunc*)       &dc_callvm_call_x86_syscall_int80h_bsd
+, (DCshortvmfunc*)      &dc_callvm_call_x86_syscall_int80h_bsd
+, (DCintvmfunc*)        &dc_callvm_call_x86_syscall_int80h_bsd
+, (DClongvmfunc*)       &dc_callvm_call_x86_syscall_int80h_bsd
+, (DClonglongvmfunc*)   &dc_callvm_call_x86_syscall_int80h_bsd
+, (DCfloatvmfunc*)      &dc_callvm_call_x86_syscall_int80h_bsd
+, (DCdoublevmfunc*)     &dc_callvm_call_x86_syscall_int80h_bsd
+, (DCpointervmfunc*)    &dc_callvm_call_x86_syscall_int80h_bsd
 , NULL /* callStruct */
 };
 
 
-/* win32/this/ms callvm allocator */
-
-DCCallVM* dcNewCallVM_x86_win32_this_ms(DCsize size) 
-{ 
-  return dc_callvm_new_x86( &gVT_x86_win32_this_ms, size );
-}
-
 #endif
 
 
@@ -619,50 +594,52 @@ DCCallVM* dcNewCallVM_x86_win32_this_ms(DCsize size)
 
 void dc_callvm_mode_x86(DCCallVM* in_self, DCint mode)
 {
-  DCCallVM_x86* self = (DCCallVM_x86*) in_self;
-  DCCallVM_vt*  vt;
+  DCCallVM_x86* self = (DCCallVM_x86*)in_self;
+  DCCallVM_vt* vt;
+
   switch(mode) {
+    case DC_CALL_C_DEFAULT:
     case DC_CALL_C_ELLIPSIS:
     case DC_CALL_C_ELLIPSIS_VARARGS:
-    case DC_CALL_C_DEFAULT:
-#if defined(DC_PLAN9) /* Plan9 (and forks) have their own calling convention (and no support for foreign ones). */
+/* Plan9 (and forks) have their own calling convention (and no support for foreign ones). */
+#if defined(DC_PLAN9)
     case DC_CALL_C_X86_PLAN9:          vt = &gVT_x86_plan9;          break;
 #else
-    case DC_CALL_C_X86_CDECL:          vt = &gVT_x86_cdecl;          break;
+    case DC_CALL_C_X86_CDECL:          vt = &gVT_x86_cdecl;          break; // also handles DC_CALL_C_X86_WIN32_THIS_GNU
     case DC_CALL_C_X86_WIN32_STD:      vt = &gVT_x86_win32_std;      break;
     case DC_CALL_C_X86_WIN32_FAST_MS:  vt = &gVT_x86_win32_fast_ms;  break;
     case DC_CALL_C_X86_WIN32_THIS_MS:  vt = &gVT_x86_win32_this_ms;  break;
     case DC_CALL_C_X86_WIN32_FAST_GNU: vt = &gVT_x86_win32_fast_gnu; break;
-    case DC_CALL_C_X86_WIN32_THIS_GNU: vt = &gVT_x86_cdecl;          break;
-    case DC_CALL_SYS_DEFAULT:         
+    case DC_CALL_SYS_DEFAULT:
 # if defined DC_UNIX
 #   if defined DC__OS_Linux
-      vt = &gVT_x86_sys_int80h_linux; break;
+      vt = &gVT_x86_syscall_int80h_linux; break;
 #   else
-      vt = &gVT_x86_sys_int80h_bsd; break;
+      vt = &gVT_x86_syscall_int80h_bsd;   break;
 #   endif
 # else
       self->mInterface.mError = DC_ERROR_UNSUPPORTED_MODE; return;
 # endif
-    case DC_CALL_SYS_X86_INT80H_LINUX:
-      vt = &gVT_x86_sys_int80h_linux; break;
-    case DC_CALL_SYS_X86_INT80H_BSD:
-      vt = &gVT_x86_sys_int80h_bsd; break;
+    case DC_CALL_SYS_X86_INT80H_LINUX: vt = &gVT_x86_syscall_int80h_linux; break;
+    case DC_CALL_SYS_X86_INT80H_BSD:   vt = &gVT_x86_syscall_int80h_bsd;   break;
 #endif
     default: 
-      self->mInterface.mError = DC_ERROR_UNSUPPORTED_MODE; return;
+      self->mInterface.mError = DC_ERROR_UNSUPPORTED_MODE;
+      return;
   }
-  self->mInterface.mVTpointer = vt;
+  dc_callvm_base_init(&self->mInterface, vt);
 }
 
-/* new */
-
+/* Public API. */
 DCCallVM* dcNewCallVM(DCsize size)
 {
-#if defined(DC__OS_Plan9)
-  return dcNewCallVM_x86_plan9(size);
-#else
-  return dcNewCallVM_x86_cdecl(size);
-#endif
+  DCCallVM_x86* p = (DCCallVM_x86*)dcAllocMem(sizeof(DCCallVM_x86)+size);
+
+  dc_callvm_mode_x86((DCCallVM*)p, DC_CALL_C_DEFAULT);
+
+  dcVecInit(&p->mVecHead, size);
+  dc_callvm_reset_x86((DCCallVM*)p);
+
+  return (DCCallVM*)p;
 }
 
