@@ -6,7 +6,7 @@
  Description: 
  License:
 
-   Copyright (c) 2011-2015 Daniel Adler <dadler@uni-goettingen.de>,
+   Copyright (c) 2011-2018 Daniel Adler <dadler@uni-goettingen.de>,
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -68,6 +68,6 @@ int main(int argc, char* argv[])
 
   dcTest_deInitPlatform();
 
-  return 0;
+  return !total;
 }
 
