@@ -3,10 +3,10 @@
  Package: dyncall
  Library: test
  File: test/suite/main.c
- Description: 
+ Description:
  License:
 
-   Copyright (c) 2007-2015 Daniel Adler <dadler@uni-goettingen.de>, 
+   Copyright (c) 2007-2021 Daniel Adler <dadler@uni-goettingen.de>,
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -89,13 +89,13 @@ void init()
     valueDouble[i]   = (DCdouble)  (i);
     valuePointer[i]  = (DCpointer) (ptrdiff_t) (i);
     valueFloat[i]    = (DCfloat)   (i);
-  } 
+  }
 }
 
 
 void push(DCCallVM* pCall, int select, int pos)
 {
-  switch(select) 
+  switch(select)
   {
     case ID_BOOL: dcArgBool    ( pCall, valueBool    [pos] ); break;
     case ID_INT: dcArgInt     ( pCall, valueInt     [pos] ); break;
@@ -107,10 +107,10 @@ void push(DCCallVM* pCall, int select, int pos)
 }
 
 
-#define assert(x) if (!(x)) return DC_FALSE
+#define test(x) if (!(x)) return DC_FALSE
 
 
-DCbool test(int x)
+DCbool test_case(int x)
 {
   int y = x;
   int selects[NARGS] = { 0, };
@@ -120,21 +120,21 @@ DCbool test(int x)
   dcReset(pCall);
   clearValues();
 
-  for(pos = 0; y>0; ++pos) 
+  for(pos = 0; y>0; ++pos)
   {
-    int select = (y-1) % NTYPES; 
+    int select = (y-1) % NTYPES;
     selects[pos] = select;
     push(pCall,select,pos);
     y = (y-1) / NTYPES;
   }
   dcCallVoid(pCall,getFunc(x));
-  
-  assert( getId() == x );
-  
+
+  test( getId() == x );
+
   for(i = 0;i<pos;++i) {
-    assert( equals( selects[i], i, getArg(i) ) );      
+    test( equals( selects[i], i, getArg(i) ) );
   }
-  
+
   dcFree(pCall);
   return DC_TRUE;
 }
@@ -153,7 +153,7 @@ DCbool run_range(int from, int to)
   int i;
   for(i=from; i<to; ++i) {
     printf("%d:",i);
-    r = test(i);
+    r = test_case(i);
     printf("%d\n", r);
     tr &= r;
   }
@@ -170,7 +170,7 @@ int main(int argc, char* argv[])
   init();
   if (argc == 2) {
     int index = atoi(argv[1]);
-    success = run_range( index, index+1 ); 
+    success = run_range( index, index+1 );
   } else if (argc == 3) {
     int from = atoi(argv[1]);
     int to   = atoi(argv[2])+1;
@@ -180,9 +180,10 @@ int main(int argc, char* argv[])
     success = run_range(0,ncalls);
   }
 
-  printf("result: suite: %s\n", success ? "1" : "0");
+  printf("result: suite: %d\n", success);
 
   dcTest_deInitPlatform();
 
-  return (success) ? 0 : -1;
+  return !success;
 }
+
