@@ -3,10 +3,10 @@
  Package: dyncall
  Library: test
  File: test/suite2/main.cc
- Description: 
+ Description:
  License:
 
-   Copyright (c) 2007-2015 Daniel Adler <dadler@uni-goettingen.de>, 
+   Copyright (c) 2007-2018 Daniel Adler <dadler@uni-goettingen.de>,
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -88,12 +88,12 @@ bool test(int x)
   const DCsigchar* ptr = sig;
   DCsigchar ch;
   int pos;
- 
+
   pos = 0;
 
   pCall = dcNewCallVM(4096);
   dcReset(pCall);
- 
+
   while ( (ch=*ptr++) != '\0' ) {
     switch(ch) {
       case DC_SIGCHAR_BOOL:     dcArgBool    ( pCall, valueBool    [pos] ); break;
@@ -111,8 +111,8 @@ bool test(int x)
 
   dcCallVoid( pCall, fi->funcptr );
 
- 
-  if ( getId() == x ) { 
+
+  if ( getId() == x ) {
 
     ptr = sig;
     pos = 0;
@@ -137,7 +137,7 @@ bool test(int x)
   }
 
   printf("%d-%s:%d\n", x, sig, r);
-   
+
   dcFree(pCall);
 
   return r;
@@ -162,7 +162,7 @@ int main(int argc, char* argv[])
   init();
   if (argc == 2) {
     int index = atoi(argv[1]);
-    success = run_range( index, index+1 ); 
+    success = run_range( index, index+1 );
   } else if (argc == 3) {
     int from = atoi(argv[1]);
     int to   = atoi(argv[2])+1;
@@ -171,11 +171,11 @@ int main(int argc, char* argv[])
     success = run_range(0,NCASES);
   }
 
-  printf("result: suite2: %s\n", success ? "1" : "0");
+  printf("result: suite2: %d\n", success);
 
   dcTest_deInitPlatform();
 
-  return (success) ? 0 : -1;
+  return !success;
 }
 
 }  // extern "C"
