@@ -6,7 +6,7 @@
  Description: 
  License:
 
-   Copyright (c) 2007-2015 Daniel Adler <dadler@uni-goettingen.de>, 
+   Copyright (c) 2007-2018 Daniel Adler <dadler@uni-goettingen.de>, 
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -169,11 +169,11 @@ int main(int argc, char* argv[])
     success = run_range(0,NCASES);
   }
 
-  printf("result: suite2_x86win32std: %s\n", success ? "1" : "0");
+  printf("result: suite2_x86win32std: %d\n", success);
   
   dcTest_deInitPlatform();
 
-  return (success) ? 0 : -1;
+  return !success;
 }
 
 }  // extern "C"
