@@ -3,10 +3,10 @@
  Package: dyncall
  Library: test
  File: test/suite3/main.cc
- Description: 
+ Description:
  License:
 
-   Copyright (c) 2007-2015 Daniel Adler <dadler@uni-goettingen.de>, 
+   Copyright (c) 2007-2018 Daniel Adler <dadler@uni-goettingen.de>,
                            Tassilo Philipp <tphilipp@potion-studios.com>
 
    Permission to use, copy, modify, and distribute this software for any
@@ -69,13 +69,13 @@ void init()
     valueLongLong[i] = DClonglong(i);
     valueDouble[i]   = DCdouble(i);
     valueFloat[i]    = DCfloat(i);
-  } 
+  }
 }
 
 
 void push(DCCallVM* pCall, int select, int pos)
 {
-  switch(select) 
+  switch(select)
   {
     case 0: dcArgInt     ( pCall, valueInt     [pos] ); break;
     case 1: dcArgLongLong( pCall, valueLongLong[pos] ); break;
@@ -85,10 +85,10 @@ void push(DCCallVM* pCall, int select, int pos)
 }
 
 
-#define assert(x) if (!(x)) return false
+#define test(x) if (!(x)) return false
 
 
-bool test(int x)
+bool test_case(int x)
 {
   clearValues();
 
@@ -97,21 +97,21 @@ bool test(int x)
   int y = x;
   int selects[NARGS] = { 0, };
   int pos = 0;
-  for(pos = 0;y>0;++pos) 
+  for(pos = 0;y>0;++pos)
   {
-    int select = (y-1) % NTYPES; 
+    int select = (y-1) % NTYPES;
     selects[pos] = select;
     push(pCall,select,pos);
     y = (y-1) / NTYPES;
   }
   dcCallVoid(pCall,getFunc(x));
-  
-  assert( getId() == x );
-  
+
+  test( getId() == x );
+
   for(int i = 0;i<pos;++i) {
-    assert( equals( selects[i], i, getArg(i) ) );      
+    test( equals( selects[i], i, getArg(i) ) );
   }
-  
+
   dcFree(pCall);
   return true;
 }
@@ -129,7 +129,7 @@ bool run_range(int from, int to)
   bool tr = true;
   for (int i = from ; i < to ; ++i ) {
     printf("%d:",i);
-    bool r = test(i);
+    bool r = test_case(i);
     printf("%d\n", r);
     tr &= r;
   }
@@ -146,7 +146,7 @@ int main(int argc, char* argv[])
   init();
   if (argc == 2) {
     int index = atoi(argv[1]);
-    success = run_range( index, index+1 ); 
+    success = run_range( index, index+1 );
   } else if (argc == 3) {
     int from = atoi(argv[1]);
     int to   = atoi(argv[2])+1;
@@ -156,11 +156,11 @@ int main(int argc, char* argv[])
     success = run_range(0,ncalls);
   }
 
-  printf("result: suite3: %s\n", success ? "1" : "0");
+  printf("result: suite3: %d\n", success);
 
   dcTest_deInitPlatform();
 
-  return (success) ? 0 : -1;
+  return !success;
 }
 
 }  // extern "C"
